const config = require('./config');

process.env.NODE_ENV = config.env;
const path = require('path');
const express = require('express');
const webpack = require('webpack');
const opn = require('opn');
const webpackConfig = require('./webpack.dev.conf');

const app = express();
const compiler = webpack(webpackConfig);

const devMiddleware = require('webpack-dev-middleware')(compiler, {
  publicPath: '/',
  stats: {
    colors: true,
    chunks: false
  }
});

const hotMiddleware = require('webpack-hot-middleware')(compiler);
// force page reload when html-webpack-plugin template changes
compiler.plugin('compilation', function (compilation) {
  compilation.plugin('html-webpack-plugin-after-emit', function (data, cb) {
    hotMiddleware.publish({ action: 'reload' });
    cb();
  });
});

// handle fallback for HTML5 history API
app.use(require('connect-history-api-fallback')());

// serve webpack bundle output
app.use(devMiddleware);

// enable hot-reload and state-preserving
// compilation error display
app.use(hotMiddleware);

app.use('/', function (req, res, next) {
  if (req.originalUrl.startsWith('/static')) {
    next();
  } else {
    res.redirect(webpackConfig.output.index);
  }
});

// serve pure static assets
const staticPath = path.posix.join(config.assetsPublicPath, config.assetsSubDirectory);
app.use(staticPath, express.static('./src/static'));

// default port where dev server listens for incoming traffic
const port = config.port;
module.exports = app.listen(port, function (err) {
  if (err) {
    console.log(err);
    return;
  }
  const uri = 'http://localhost:' + port + '/examples/index.html';
  console.log('Listening at ' + uri + '\n');
  opn(uri);
});
